PALM-meteo: palmmeteo.logging Namespace Reference

PALM-meteo

Loading...
Searching...
No Matches
Classes | Functions | Variables
palmmeteo.logging Namespace Reference

## Classes
class | LoggingLevel

## Functions
| die (s, *args, **kwargs)
| warn (s, *args, **kwargs)
| configure_log (verbosity, log_datetime=False)

## Variables
str | dtf = '%Y-%m-%d %H:%M:%S '
| log_output = sys.stdout.write
| error_output = sys.stderr.write
| log = LoggingLevel(True)
| verbose = LoggingLevel(False)

## Function Documentation

## ◆ configure_log()

palmmeteo.logging.configure_log | ( |  | verbosity,
|  |  | log_datetime = `False`
| ) |  |

## ◆ die()

palmmeteo.logging.die | ( |  | s,
|  | * | args,
|  | ** | kwargs
| ) |  |

    Write message to error output and exit with status 1.

## ◆ warn()

palmmeteo.logging.warn | ( |  | s,
|  | * | args,
|  | ** | kwargs
| ) |  |

    Write message to error output.

## Variable Documentation

## ◆ dtf

str palmmeteo.logging.dtf = '%Y-%m-%d %H:%M:%S '

## ◆ error_output

palmmeteo.logging.error_output = sys.stderr.write

## ◆ log

palmmeteo.logging.log = LoggingLevel(True)

## ◆ log_output

palmmeteo.logging.log_output = sys.stdout.write

## ◆ verbose

palmmeteo.logging.verbose = LoggingLevel(False)